@@ -15,6 +15,7 @@ from .material import EnergyMaterial, EnergyMaterialNoMass, \
 from .programtype import ProgramTypeAbridged, ProgramType
 from .load import PeopleAbridged, LightingAbridged, ElectricEquipmentAbridged, \
     GasEquipmentAbridged, InfiltrationAbridged, VentilationAbridged, SetpointAbridged
+from .ventcool import VentilationControlAbridged, VentilationOpening
 from .schedule import ScheduleTypeLimit, ScheduleRulesetAbridged, \
     ScheduleFixedIntervalAbridged, ScheduleRuleset, ScheduleFixedInterval
 from .hvac import IdealAirSystemAbridged
@@ -62,6 +63,12 @@ class DoorEnergyPropertiesAbridged(NoExtraBaseModel):
         'global_construction_set.'
     )
 
+    vent_opening: VentilationOpening = Field(
+        default=None,
+        description='An optional VentilationOpening to specify the operable '
+        'portion of the Door.'
+    )
+
 
 class ApertureEnergyPropertiesAbridged(NoExtraBaseModel):
 
@@ -77,6 +84,12 @@ class ApertureEnergyPropertiesAbridged(NoExtraBaseModel):
         'global_construction_set.'
     )
 
+    vent_opening: VentilationOpening = Field(
+        default=None,
+        description='An optional VentilationOpening to specify the operable '
+        'portion of the Aperture.'
+    )
+
 
 class FaceEnergyPropertiesAbridged(NoExtraBaseModel):
 
@@ -159,21 +172,18 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         description='Setpoint object for the temperature setpoints of the Room.'
     )
 
+    window_vent_control: VentilationControlAbridged = Field(
+        default=None,
+        description='An optional VentilationControl object to dictate the opening '
+        'of windows. If None, the windows will never open.'
+    )
+
 
 class ModelEnergyProperties(NoExtraBaseModel):
 
     type: constr(regex='^ModelEnergyProperties$') = \
         'ModelEnergyProperties'
 
-    global_construction_set: str = Field(
-        default=None,
-        min_length=1,
-        max_length=100,
-        description='Identifier for the ConstructionSet to be used for all '
-        'objects lacking their own construction or a parent Room construction_set. '
-        'This ConstructionSet must appear under the Model construction_sets.'
-    )
-
     construction_sets: List[Union[ConstructionSetAbridged, ConstructionSet]] = Field(
         default=None,
         description='List of all unique ConstructionSets in the Model.'
